#!/usr/bin/perl -w
#
# Test for namazu. with MaxHit, MaxMatch.
#

use strict;
require Cwd;
require 'pltests.pl';

my $cwd = Cwd::getcwd();
my $LOG = "$cwd/test-log";
my $INDEX = "$cwd/idx8";
my $NAMAZU = pltests::binpath('namazu');

my $RC = "$cwd/tmp.namazurc";
my $MSG0 = 'No document matching your query.';
my $MSG1 = 'Too many documents hit. Ignored';
my $MSG2 = 'Too many words matched. Ignored';

my $cmd;
my $result;

delete $ENV{'LANG'};
delete $ENV{'LANGUAGE'};
$ENV{'LC_ALL'} = 'C';
delete $ENV{'LC_MESSAGE'};
delete $ENV{'NAMAZURC'};

pltests::putline($LOG, "  *** starting $0");

# Tests for MaxHit.
#   foo => 1 page indexed.
#   bar => 2 page indexed.
#   baz => 3 page indexed.

pltests::putline($RC, "MaxHit 0");

$cmd = "$NAMAZU -f $RC \"foo\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG1/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"bar\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG1/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"baz\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG1/s) {
    exit 1;
}


if (-f $RC) {
    unlink $RC;
}
pltests::putline($RC, "MaxHit 1");

$cmd = "$NAMAZU -f $RC \"foo\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG1/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"bar\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG1/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"baz\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG1/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"foo and bzz\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG0/s) {
    exit 1;
}


if (-f $RC) {
    unlink $RC;
}
pltests::putline($RC, "MaxHit 2");

$cmd = "$NAMAZU -f $RC \"foo\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG0/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"bar\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG0/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"baz\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG0/s) {
    exit 1;
}


if (-f $RC) {
    unlink $RC;
}
pltests::putline($RC, "MaxHit 3");

$cmd = "$NAMAZU -f $RC \"foo\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG0/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"bar\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG0/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"baz\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG0/s) {
    exit 1;
}

# Tests for MaxMatch.
#   f* => 1 word matched.       (foo)
#   b* => 2 words matched.      {bar,baz}

if (-f $RC) {
    unlink $RC;
}
pltests::putline($RC, "MaxMatch 0");

$cmd = "$NAMAZU -f $RC \"f*\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG2/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"b*\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG2/s) {
    exit 1;
}

if (-f $RC) {
    unlink $RC;
}
pltests::putline($RC, "MaxMatch 1");

$cmd = "$NAMAZU -f $RC \"f*\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG2/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"b*\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result !~ /$MSG2/s) {
    exit 1;
}

if (-f $RC) {
    unlink $RC;
}
pltests::putline($RC, "MaxMatch 2");

$cmd = "$NAMAZU -f $RC \"f*\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG2/s) {
    exit 1;
}

$cmd = "$NAMAZU -f $RC \"b*\" $INDEX";
pltests::putline($LOG, $cmd);
$result = `$cmd`;
unless (defined $result) {
    exit 1;
}
if ($result =~ /$MSG2/s) {
    exit 1;
}

exit 0;

END {
    if (-f $RC) {
        unlink $RC;
    }
}

